@@ -36,6 +36,7 @@
 #include "media.h"
 
 
+
 static Exec *burn_args = NULL;
 
 
@@ -46,7 +47,6 @@ burn_show_start_dlg(const BurnType burn_type)
 	if(burn_args != NULL)
 		exec_delete(burn_args);
 	burn_args = NULL;
-
 	StartDlg *dlg = startdlg_new(burn_type);
 	if(gtk_dialog_run(dlg->dialog) != GTK_RESPONSE_OK)
     {
@@ -80,7 +80,6 @@ burn_run_process()
 	progressdlg_delete(dlg);
 }
 
-
 static void
 burn_cd_iso(const gchar *file)
 {
@@ -92,8 +91,8 @@ burn_cd_iso(const gchar *file)
 	{
 		burn_args = exec_new(_("Burning CD image"), _("Please wait while the CD image you selected is burned to CD."));
         mkisofs_add_calc_iso_size_args(exec_cmd_new(burn_args), file);
-		cdrecord_add_iso_args(exec_cmd_new(burn_args), file);
-		burn_run_process();
+        cdrecord_add_iso_args(exec_cmd_new(burn_args), file);
+        burn_run_process();
         startdlg_delete(dlg);
 	}
 }
@@ -110,7 +109,7 @@ burn_dvd_iso(const gchar *file)
         gnomebaker_show_msg_dlg(NULL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, GTK_BUTTONS_NONE,
         _("The file you have selected is not a DVD image. Please select a DVD image to burn."));*/
     gchar *mime = gbcommon_get_mime_type(file);
-    if((g_ascii_strcasecmp(mime, "application/x-cd-image") == 0) ||
+    if((g_ascii_strcasecmp(mime, "application/x-cd-image") == 0) || gbcommon_str_has_suffix(file, ".raw") ||
             (gnomebaker_show_msg_dlg(NULL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, GTK_BUTTONS_NONE,
             _("The file you have selected seems not to be a DVD image. Do you really want to write it to DVD?")) == GTK_RESPONSE_YES))
     {
@@ -155,7 +154,7 @@ burn_cd_image_file(const gchar *file)
         gnomebaker_show_msg_dlg(NULL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, GTK_BUTTONS_NONE,
         _("The file you have selected is not a cd image. Please select a cd image to burn."));*/
     gchar *mime = gbcommon_get_mime_type(file);
-    if(g_ascii_strcasecmp(mime, "application/x-cd-image") == 0)
+    if((g_ascii_strcasecmp(mime, "application/x-cd-image") == 0) || gbcommon_str_has_suffix(file, ".raw"))
         burn_cd_iso(file);
     else if(gbcommon_str_has_suffix(file, ".cue") || gbcommon_str_has_suffix(file, ".toc"))
         burn_cue_or_toc(file);
@@ -394,9 +393,9 @@ burn_blank_cdrw()
     StartDlg *dlg = burn_show_start_dlg(blank_cdrw);
 	if(dlg != NULL)
 	{
-		burn_args = exec_new(_("Blanking CD"), _("Please wait while the CD is blanked."));
-		cdrecord_add_blank_args(exec_cmd_new(burn_args));
-		burn_run_process();
+		burn_args = exec_new(_("Blanking CD"), _("Please wait while the CD is blanked."));        		
+        cdrecord_add_blank_args(exec_cmd_new(burn_args));
+        burn_run_process();
         startdlg_delete(dlg);
 	}
 }
