@@ -32,7 +32,8 @@
 #include <fcntl.h>
 #include <stdlib.h>
 
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__sun)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__sun) \
+	|| defined(__OpenBSD__)
 #include <sys/cdio.h>
 #define CDROM_DRIVE_STATUS     0x5326
 #define CDS_NO_DISC        1
@@ -111,7 +112,10 @@ devices_add_device(const gchar *device_name, const gchar *device_id,
 		g_strstrip(*line);
 		if((*line)[0] != '#') /* ignore commented out lines */
 		{
-			gchar node[64], mount[64];
+			gchar *node, *mount;
+			int line_size = strlen(*line);
+			node = g_new0(gchar, line_size);
+			mount = g_new0(gchar, line_size);
 			if(sscanf(*line, "%s\t%s", node, mount) == 2)
 			{
 				GB_TRACE("devices_add_device - node [%s] mount [%s]\n", node, mount);
@@ -134,8 +138,14 @@ devices_add_device(const gchar *device_name, const gchar *device_id,
 				}
 
 				if(mount_point != NULL)
+				{
+					g_free(node);
+					g_free(mount);
 					break;
+				}
 			}
+			g_free(node);
+			g_free(mount);
 		}
 		++line;
 	}
@@ -474,6 +484,7 @@ devices_get_scsi_device(const gchar *device_node, const gchar *device_node_path,
 
 							*model_name = g_strdup_printf("%s %s", vendor, model);
 							*device_id = g_strdup_printf("%d,%d,%d", scsihost, scsiid, scsilun);
+							printf("vendor = %s, model = %s device = %s\n", vendor, model, device);
 							break;
 						}
 					}
@@ -703,11 +714,11 @@ devices_eject_disk(const gchar *device_key)
     else
     {
         /* Use ioctl to send the CDROMEJECT (CDIOCEJECT on FreeBSD) command to the device */
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__)
         if(ioctl(cdrom, CDIOCEJECT, 0) < 0)
-            ret = TRUE;
-        else
             g_warning("devices_eject_disk - ioctl failed");
+        else
+            ret = TRUE;
 #else
         if(ioctl(cdrom, CDROMEJECT, 0) < 0)
             g_warning("devices_eject_disk - ioctl failed");
