@@ -704,6 +704,8 @@ mkisofs_add_common_args(ExecCmd *e, StartDlg *start_dlg, const gchar *arguments_
     g_return_if_fail(start_dlg != NULL);
 
     const gchar *text = gtk_entry_get_text(start_dlg->volume_id);
+    if(preferences_get_bool(GB_DIR_TOO_DEEP))
+	exec_cmd_add_arg(e, "-D");
     if(text != NULL && strlen(text) > 0)
     {
         exec_cmd_add_arg(e, "-V");
@@ -868,7 +870,7 @@ mkisofs_add_calc_iso_size_args(ExecCmd *e, const gchar *iso)
 			exec_cmd_add_arg(e, "mkisofs");			
 			break;
 		case BACKEND_WODIM:
-			exec_cmd_add_arg(e, "genisofs");
+			exec_cmd_add_arg(e, "genisoimage");
 			break;			
 	}
 
@@ -1475,6 +1477,8 @@ genisoimage_add_common_args(ExecCmd *e, StartDlg *start_dlg, const gchar *argume
     g_return_if_fail(start_dlg != NULL);
 
     const gchar *text = gtk_entry_get_text(start_dlg->volume_id);
+    if(preferences_get_bool(GB_DIR_TOO_DEEP))
+	exec_cmd_add_arg(e, "-D");
     if(text != NULL && strlen(text) > 0)
     {
         exec_cmd_add_arg(e, "-V");
@@ -1707,13 +1711,9 @@ dvdformat_add_args(ExecCmd *cmd)
 		else
 			exec_cmd_add_arg(cmd, "-force");
 	}
-	else if(!preferences_get_bool(GB_FAST_FORMAT))
-	{
-		exec_cmd_add_arg(cmd, "-blank=full");
-	}
     else
     {
-        exec_cmd_add_arg(cmd, "-blank");
+        exec_cmd_add_arg(cmd, "-lead-out");
     }
 }
 
