@@ -71,7 +71,7 @@ preferences_init()
 			preferences_set_bool(GB_SCROLL_OUTPUT, TRUE);
 			preferences_set_string(GB_WRITE_MODE, _("default"));
             preferences_set_string(GB_DVDWRITE_MODE, _("default"));
-			preferences_set_bool(GB_ALWAYS_SCAN, TRUE);
+			preferences_set_bool(GB_ALWAYS_SCAN, FALSE);
 			preferences_set_bool(GB_SHOW_FILE_BROWSER, TRUE);
             preferences_set_bool(GB_JOLIET, TRUE);
             preferences_set_bool(GB_ROCKRIDGE, TRUE);
@@ -80,6 +80,7 @@ preferences_init()
             preferences_set_int(GB_DATA_DISK_SIZE, 0);
             preferences_set_int(GB_AUDIO_DISK_SIZE, 0);
             preferences_set_bool(GB_CDRECORD_FORCE, FALSE);
+	    preferences_set_bool(GB_DIR_TOO_DEEP, FALSE);
 			preferences_set_int(GB_BACKEND, preferences_get_default_backend());
 
             gchar *last_iso = preferences_get_default_iso();
